@@ -12,6 +12,13 @@ class AdapterManagerConfiguration:
 
         self.__adapter_mode = app_properties.get('adaptermode', AdapterMode.USE_FILTER)
 
+        __automatic_creation_test_cases = app_properties.get('automaticcreationtestcases')
+
+        if __automatic_creation_test_cases and __automatic_creation_test_cases == 'true':
+            self.__automatic_creation_test_cases = True
+        else:
+            self.__automatic_creation_test_cases = False
+
     @adapter_logger
     def get_test_run_id(self):
         return self.__test_run_id
@@ -23,3 +30,7 @@ class AdapterManagerConfiguration:
     @adapter_logger
     def get_mode(self):
         return self.__adapter_mode
+
+    @adapter_logger
+    def should_automatic_creation_test_cases(self):
+        return self.__automatic_creation_test_cases
